Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5501)

Unified Diff: chrome/browser/sync/glue/http_bridge.h

Issue 7846007: net: Rename URLRequestStatus::os_error_. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: fix os_error_code Created 9 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/safe_browsing/protocol_manager.cc ('k') | chrome/browser/sync/glue/http_bridge.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/sync/glue/http_bridge.h
diff --git a/chrome/browser/sync/glue/http_bridge.h b/chrome/browser/sync/glue/http_bridge.h
index d19e03435060c21f50a43ca47e45f6d5267a6dcd..b5d8236ac5eeb10a71bacc64dee8d0c98b46b192 100644
--- a/chrome/browser/sync/glue/http_bridge.h
+++ b/chrome/browser/sync/glue/http_bridge.h
@@ -103,7 +103,7 @@ class HttpBridge : public base::RefCountedThreadSafe<HttpBridge>,
virtual void SetURL(const char* url, int port);
virtual void SetPostPayload(const char* content_type, int content_length,
const char* content);
- virtual bool MakeSynchronousPost(int* os_error_code, int* response_code);
+ virtual bool MakeSynchronousPost(int* error_code, int* response_code);
virtual void Abort();
// WARNING: these response content methods are used to extract plain old data
@@ -186,7 +186,7 @@ class HttpBridge : public base::RefCountedThreadSafe<HttpBridge>,
bool request_completed;
bool request_succeeded;
int http_response_code;
- int os_error_code;
+ int error_code;
std::string response_content;
scoped_refptr<net::HttpResponseHeaders> response_headers;
};
@@ -194,7 +194,7 @@ class HttpBridge : public base::RefCountedThreadSafe<HttpBridge>,
// This lock synchronizes use of state involved in the flow to fetch a URL
// using URLFetcher. Because we can Abort() from any thread, for example,
// this flow needs to be synchronized to gracefully clean up URLFetcher and
// return appropriate values in os_error_code.
mutable base::Lock fetch_state_lock_;
URLFetchState fetch_state_;
« no previous file with comments | « chrome/browser/safe_browsing/protocol_manager.cc ('k') | chrome/browser/sync/glue/http_bridge.cc » ('j') | no next file with comments »
@@ -194,7 +194,7 @@ class HttpBridge : public base::RefCountedThreadSafe<HttpBridge>,
// using URLFetcher. Because we can Abort() from any thread, for example,
// this flow needs to be synchronized to gracefully clean up URLFetcher and
- // return appropriate values in os_error_code.
+ // return appropriate values in |error_code|.
mutable base::Lock fetch_state_lock_;
URLFetchState fetch_state_;

Powered by Google App Engine
This is Rietveld 408576698